# Algomojo Webhook Signal Library

This Python package allows traders to place **BUY/SELL/SHORT/COVER** signals via Algomojo's webhook API.

## Installation

```bash
pip install algomojo-webhook-signal
```
